Enum network::noise::error::NoiseHandshakeError [−][src]
pub enum NoiseHandshakeError {
Show 18 variants
MissingServerPublicKey,
BuildClientHandshakeMessageFailed(NoiseError),
ClientWriteFailed(Error),
ClientReadFailed(Error),
ClientFlushFailed(Error),
ClientFinalizeFailed(NoiseError),
ServerReadFailed(Error),
InvalidClientPeerId(String),
SelfDialDetected,
ClientExpectingDifferentPubkey(ShortHexStr, String),
ServerParseClient(ShortHexStr, NoiseError),
UnauthenticatedClientPubkey(ShortHexStr, String),
UnauthenticatedClient(ShortHexStr, PeerId),
ClientPeerIdMismatch(ShortHexStr, PeerId, PeerId),
MissingAntiReplayTimestamp(ShortHexStr),
ServerReplayDetected(ShortHexStr, u64),
BuildServerHandshakeMessageFailed(ShortHexStr, NoiseError),
ServerWriteFailed(ShortHexStr, Error),
}Expand description
Different errors than can be raised when negotiating a Noise handshake.
Variants
BuildClientHandshakeMessageFailed(NoiseError)Tuple Fields of BuildClientHandshakeMessageFailed
0: NoiseErrorClientWriteFailed(Error)Tuple Fields of ClientWriteFailed
0: ErrorClientReadFailed(Error)Tuple Fields of ClientReadFailed
0: ErrorClientFlushFailed(Error)Tuple Fields of ClientFlushFailed
0: ErrorClientFinalizeFailed(NoiseError)Tuple Fields of ClientFinalizeFailed
0: NoiseErrorServerReadFailed(Error)Tuple Fields of ServerReadFailed
0: ErrorInvalidClientPeerId(String)Tuple Fields of InvalidClientPeerId
0: StringClientExpectingDifferentPubkey(ShortHexStr, String)Tuple Fields of ClientExpectingDifferentPubkey
0: ShortHexStr1: StringServerParseClient(ShortHexStr, NoiseError)Tuple Fields of ServerParseClient
0: ShortHexStr1: NoiseErrorUnauthenticatedClientPubkey(ShortHexStr, String)Tuple Fields of UnauthenticatedClientPubkey
0: ShortHexStr1: StringUnauthenticatedClient(ShortHexStr, PeerId)Tuple Fields of UnauthenticatedClient
0: ShortHexStr1: PeerIdClientPeerIdMismatch(ShortHexStr, PeerId, PeerId)Tuple Fields of ClientPeerIdMismatch
MissingAntiReplayTimestamp(ShortHexStr)Tuple Fields of MissingAntiReplayTimestamp
0: ShortHexStrServerReplayDetected(ShortHexStr, u64)Tuple Fields of ServerReplayDetected
0: ShortHexStr1: u64BuildServerHandshakeMessageFailed(ShortHexStr, NoiseError)Tuple Fields of BuildServerHandshakeMessageFailed
0: ShortHexStr1: NoiseErrorServerWriteFailed(ShortHexStr, Error)Tuple Fields of ServerWriteFailed
0: ShortHexStr1: ErrorImplementations
Errors that are either clear bugs or indicate some security issue. Should immediately alert an engineer if we hit one of these errors.